@@ -29,7 +29,7 @@ class MenuTreeNode(template.Node):
         except Menu.DoesNotExist:
             return []
         if root_menu:
-            return root_menu.get_children()
+            return root_menu.get_children().filter(published=True)
 
     def render(self, context):
         roots = self.menu_items()
